/******************************************************************************/
/* CD_DSP.H								      */
/******************************************************************************/

#ifndef	__HEADER_CD_DSP
#define	__HEADER_CD_DSP		__HEADER_CD_DSP

/* -------------------------------------------------------------------------- */
/* different memory mapped register addresses at DSP Host Interface */

#define	DSP_ICR		0xFFFFA200L
#define	DSP_CVR		0xFFFFA201L
#define	DSP_ISR		0xFFFFA202L
#define	DSP_IVR		0xFFFFA203L

#define	DSP_TRANSLONG	0xFFFFA204L

#define	DSP_RXH		0xFFFFA205L
#define	DSP_RXM		0xFFFFA206L
#define	DSP_RXL		0xFFFFA207L

#define	DSP_TXH		0xFFFFA205L
#define	DSP_TXM		0xFFFFA206L
#define	DSP_TXL		0xFFFFA207L

/* -------------------------------------------------------------------------- */
/* general purpose flags in the ISR can be used as semaphores for */
/* transferring data between host processor and the DSP - these flags */
/* are used by DSP to inform host processor to do stuff */

#define	DSP_ISR_RXDF	0x01		/* receive data register full flag */
#define	DSP_ISR_TXDE	0x02		/* transmit data register empty */
#define	DSP_ISR_TRDY	0x04		/* transmit ready */
#define	DSP_ISR_GPMASK	0x18		/* general purpose flags - bits 3 and 4 */
#define	DSP_ISR_DMA	0x40		/* DMA transfer flag */
#define	DSP_ISR_HREQ	0x80		/* Host Request */

/* DSP ISR GP bits are used as semaphores - as follows */

#define	DSP_ISRGP_IDLE	0x00		/* no data transfer requested */
#define	DSP_ISRGP_1STBL	0x01		/* data transfer to first block */
#define	DSP_ISRGP_2NDBL	0x02		/* data transfer to second block */

/* -------------------------------------------------------------------------- */
/* general purpose flags in the ICR can be used as semaphores for */
/* transferring data between host processor and the DSP - these flags */
/* are used by host processor to inform the DSP to do stuff */

#define	DSP_ICR_RREQ	0x01		/* receive request enable */
#define	DSP_ICR_TREQ	0x02		/* transmit request enable */
#define	DSP_ICR_GPMASK	0x18		/* general purpose flags - bits 3 and 4 */
#define	DSP_ICR_MODMASK	0x60		/* transfer mode - bits 5 and 6 */
#define	DSP_ICR_INIT	0x80		/* initialise bit */

/* mode settings */

#define	DSP_ICRMD_INTR	0x00		/* interrupt mode (DMA off) */
#define	DSP_ICRMD_DMA24	0x01		/* DMA mode - 24 bits */
#define	DSP_ICRMD_DMA16	0x02		/* DMA mode - 16 bits */
#define	DSP_ICRMD_DMA08	0x03		/* DMA mode -  8 bits */

/* DSP ICR GP bits are used as semaphores - as follows */

#define	DSP_ICRGP_IDLE	0x00		/* do not output data on SSI */
#define	DSP_ICR_GPXFER	0x01		/* transfer data on SSI */
#define	DSP_ICR_GPPAUSE	0x02		/* keep transferring data on SSI in pause mode */

#endif

/******************************************************************************/
/* End of CD_DSP.H							      */
/******************************************************************************/
