/******************************************************************************/
/* ST_CTYPE.H								      */
/******************************************************************************/

#ifndef	__HEADER_ST_CTYPE
#define	__HEADER_ST_CTYPE	__HEADER_ST_CTYPE

/* -------------------------------------------------------------------------- */

/*
 * tctype.h - standard <ctype.h> macros with TOS extensions
 * Copyright  1992 Atari Corporation
 * All Rights Reserved
 *=======================================================================
 * NOTE: this file is a plug-in replacement for your <ctype.h> file.
 * #define _NO_TCTYPE_MACROS for no inline expansion of ANSI ctype calls.
 *
 * 920225 kbad
 * 930503 Pradip K Fatehpuria
 */

/* -------------------------------------------------------------------------- */

extern	unsigned int	TCT_LEX_[];	/* Table for special chars in field name */
extern	unsigned int	TCT_[257];	/* TOS ctype table */

/* -------------------------------------------------------------------------- */
/* ctype masks */

#define UC_	( 0x0001 )	/* Upper Case */
#define LC_	( 0x0002 )	/* Lower Case */
#define NU_	( 0x0004 )	/* Number */
#define WS_	( 0x0008 )	/* White Space */
#define PU_	( 0x0010 )	/* Punctuation */
#define CC_	( 0x0020 )	/* Control char */
#define SP_	( 0x0040 )	/* Space */
#define HX_	( 0x0080 )	/* Hex digit */
#define U2_	( 0x0100 )	/* Uppercase int'l */
#define L2_	( 0x0200 )	/* Lowercase int'l */
#define SY_	( 0x0400 )	/* Symbol */
#define HB_	( 0x0800 )	/* Hebrew */
#define WC_	( 0x1000 )	/* Wildcard Char */
#define NF_	( 0x2000 )	/* Not valid in Filename */
#define PC_	( 0x4000 )	/* Pathspec Char */

#define PUNC_	( PU_ | WC_ | NF_ | PC_ )
#define ALNUM_	( UC_ | LC_ | NU_ )
#define XASCII_ ( U2_ | L2_ | SY_ | HB_ )
#define FILECH_	( UC_ | LC_ | NU_ | PU_ | U2_ | L2_ | SY_ | HB_ )
#define IALPHA_	( UC_ | LC_ | U2_ | L2_ | HB_ )

/* -------------------------------------------------------------------------- */
/* standard ctype stuff */

#ifdef _NO_TCTYPE_MACROS

int	isalnum();
int	isalpha();
int	isascii();
int	iscntrl();
int	iscsym();
int	iscsymf();
int	isdigit();
int	isgraph();
int	islower();
int	ispunct();
int	isprint();
int	isspace();
int	isupper();
int	isxdigit();

#endif

#ifndef _NO_TCTYPE_MACROS

#define isalnum(c)	( TCT_[(c)+1] & ( ALNUM_ ))
#define isalpha(c)	( TCT_[(c)+1] & ( UC_ | LC_ ))
#define	isxalpha(c)	( TCT_[(c)+1] & ( UC_ | LC_ | U2_ | L2_ ))
#define iscntrl(c)	( TCT_[(c)+1] & ( CC_ ))
#define isdigit(c)	( TCT_[(c)+1] & ( NU_ ))
#define isgraph(c)	( TCT_[(c)+1] & ( PUNC_ | ALNUM_ | XASCII_ ))
#define islower(c)	( TCT_[(c)+1] & ( LC_ ))
#define ispunct(c)	( TCT_[(c)+1] & ( PUNC_ ))
#define isprint(c)	( TCT_[(c)+1] & ( PUNC_ | ALNUM_ | XASCII_ | SP_ ))
#define isspace(c)	( TCT_[(c)+1] & ( WS_ ))
#define isupper(c)	( TCT_[(c)+1] & ( UC_ ))
#define isxdigit(c)	( TCT_[(c)+1] & ( HX_ ))

#endif

/* -------------------------------------------------------------------------- */
/* ST SUTRA specific macros */

/* valid field name characters in database */

#define	isfldchar(c)	( TCT_LEX_[(c)]==8 )

/* valid word delimitors */

#define	isword_delim(c)	( TCT_[(c)+1] & ( PUNC_ | WS_ | SY_ | HB_ ))
#define	iswp_delim(c)	( (c != '-' ) && isword_delim(c))

/* -------------------------------------------------------------------------- */
/* Extensions to ANSI */

#define _toupper(c)	((c) - 'a' + 'A')
#define _tolower(c)	((c) + 'a' - 'A')
#define toascii(c)	((c) & 127)
#define isascii(c)	((unsigned)(c) <= 127)
#define iscsym(c)	(isalnum(c) || (toascii(c) == '_'))
#define iscsymf(c)	(isalpha(c) || (toascii(c) == '_'))

int	tolower( int );
int	toupper( int );

/* -------------------------------------------------------------------------- */
/* TOS character set tolower() & toupper() */

int	Tolower( int );
int	Toupper( int );

/* Validate a character against a TEDINFO template char.
 * Return validated char or 0 if it's invalid.
 * int Tvalid(int c, int template);
 */

int	Tvalid( int, int );

/* TEDINFO validation macros
 *
 * NOTE: these differ from the current AES ones in the following details:
 * - Paths and filenames allow punctuation characters legal in GEMDOS
 * - 'p' path spec template allows '.'
 * - 'F' wild file template does not allow ':'
 * - 'a' and 'n' alpha and alnum masks don't allow symbols
 * - 'x' mask uppercase translation is done for int'l chars
 */

#define isTdigit(c)	( TCT_[(c)+1] & ( NU_ ))			/*'9'*/
#define isTupper(c)	( TCT_[(c)+1] & ( UC_ | SP_ | U2_ ))		/*'A'*/
#define isTualnum(c)	( TCT_[(c)+1] & ( UC_ | NU_ | SP_ | U2_ ))	/*'N'*/
#define isTwildpath(c)	( TCT_[(c)+1] & ( FILECH_ | WC_ | PC_ ))	/*'P'*/
#define isTpathspec(c)	( TCT_[(c)+1] & ( FILECH_ | PC_ ))		/*'p'*/
#define isTwildfile(c)	( TCT_[(c)+1] & ( FILECH_ | WC_ ))		/*'F'*/
#define isTfilename(c)	( TCT_[(c)+1] & ( FILECH_ ))			/*'f'*/
#define isTalpha(c)	( TCT_[(c)+1] & ( IALPHA_ | SP_ ))		/*'a'*/
#define isTalnum(c)	( TCT_[(c)+1] & ( IALPHA_ | NU_ | SP_ ))	/*'n'*/

/* -------------------------------------------------------------------------- */

#endif

/******************************************************************************/
/* End of ST_CTYPE.H							      */
/******************************************************************************/
