/******************************************************************************/
/* ST_PREF.C								      */
/******************************************************************************/

#include "st_def.h"
#include "st_struc.h"
#include "st_aes.h"
#include "st_bind.h"
#include "st_lib.h"
#include "st_pref.h"
#include "cd_bind.h"

#include "cdmonusa.h"

/* -------------------------------------------------------------------------- */

extern	GRECT	gl_fullbox;
extern	unsigned char	gl_pathname[];

extern	GRECT	gl_windrect;

extern	int	gl_charwide;
extern	int	gl_charhite;

/* -------------------------------------------------------------------------- */

/* preference file version number */

#define	PREF_MAJOR_VERSION	'1'
#define	PREF_MINOR_VERSION	'0'

#define	PREF_MAGIC_NO_1		'C'
#define	PREF_MAGIC_NO_2		'D'
#define	PREF_MAGIC_NO_3		'R'
#define	PREF_MAGIC_NO_4		'0'

#define	PREF_TEMP_MAGIC		10

/* -------------------------------------------------------------------------- */

/* full path name for the preference file */

static	unsigned char	prefINF_Filename[ MAX_PATHNAME ];

/******************************************************************************/
/******************************************************************************/

/* -----------------------------------------------------------------------------
 */

void	st_defl_preference()
{
/* initialise different pathnames */

	st_init_pathnames();
	st_set_curpath(gl_pathname);

/* get the pathname of the preference file name - */
/* it is same as the path from where the emulator is run */

	strcpy(prefINF_Filename, gl_pathname);
	strcat(prefINF_Filename, "CDROM.INF");

/* set the window default size */

	gl_windrect.g_x = gl_fullbox.g_x;
	gl_windrect.g_y = gl_fullbox.g_y;
	gl_windrect.g_w = gl_fullbox.g_w;
	gl_windrect.g_h = gl_fullbox.g_h;

/* initialise cd related preferences */

	cd_init_preferences();
	return;
}

/* -----------------------------------------------------------------------------
 */

int	st_save_preference()
{
register FILE	*fp;
register int	ret;
unsigned char	header[200];

	ret = FALSE;
	fp = fopen(prefINF_Filename, "wb");
	if (fp == NULL)						goto out;

	header[0] = PREF_MAJOR_VERSION;				/* major version number */
	header[1] = PREF_MINOR_VERSION;				/* minor version number */
	header[2] = PREF_MAGIC_NO_1;				/* magic number character 1 */
	header[3] = PREF_MAGIC_NO_2;				/* magic number character 2 */
	header[4] = PREF_MAGIC_NO_3;				/* magic number character 3 */
	header[5] = PREF_MAGIC_NO_4;				/* magic number character 4 */
	header[6] = PREF_TEMP_MAGIC;				/* temporary magic number */
	header[7] = 0;						/* reserved */

	(*((unsigned int *)(&header[ 8]))) = gl_windrect.g_x;	/* save the current window */
	(*((unsigned int *)(&header[10]))) = gl_windrect.g_y;	/* coordinates, to be used */
	(*((unsigned int *)(&header[12]))) = gl_windrect.g_w;	/* again when the emulator */
	(*((unsigned int *)(&header[14]))) = gl_windrect.g_h;	/* is run */

	if (!fwrite(header, (size_t)1, (size_t)16, fp))		goto out;

	if (!st_save_pathnames(fp))				goto out;
	if (!cd_save_preferences(fp))				goto out;

	ret = TRUE;

out :	if (fp)	fclose(fp);
	return(ret);
}

/* -----------------------------------------------------------------------------
 */

int	st_load_preference()
{
register FILE	*fp;
register int	ret;
register int	maxx;
register int	maxy;
register int	maxw;
register int	maxh;
unsigned char	header[200];

/* open the file to load the preferences */

	ret = FALSE;
	fp = fopen(prefINF_Filename, "rb");
	if (fp == NULL)						goto out;

/* load and check the file header */

	if (!fread(header, (size_t)1, (size_t)16, fp))		goto out;

	if (header[0] != PREF_MAJOR_VERSION)			goto out;
	if (header[1] != PREF_MINOR_VERSION)			goto out;

	if (header[2] != PREF_MAGIC_NO_1)			goto out;
	if (header[3] != PREF_MAGIC_NO_2)			goto out;
	if (header[4] != PREF_MAGIC_NO_3)			goto out;
	if (header[5] != PREF_MAGIC_NO_4)			goto out;

	if (header[6] != PREF_TEMP_MAGIC)			goto out;
	if (header[7] != 0)					goto out;

	gl_windrect.g_x = (*((unsigned int *)(&header[ 8])));	/* load the current window */
	gl_windrect.g_y = (*((unsigned int *)(&header[10])));	/* coordinates, to be used */
	gl_windrect.g_w = (*((unsigned int *)(&header[12])));	/* again when the emulator */
	gl_windrect.g_h = (*((unsigned int *)(&header[14])));	/* is run */

	if (gl_windrect.g_x < gl_fullbox.g_x)	gl_windrect.g_x = gl_fullbox.g_x;
	if (gl_windrect.g_y < gl_fullbox.g_y)	gl_windrect.g_y = gl_fullbox.g_y;

	maxx = gl_fullbox.g_w - gl_charwide * 4;
	maxy = gl_fullbox.g_h - gl_charhite * 4;
	maxw = gl_fullbox.g_w;
	maxh = gl_fullbox.g_h;

	if (gl_windrect.g_x > maxx)	gl_windrect.g_x = maxx;
	if (gl_windrect.g_y > maxy)	gl_windrect.g_y = maxy;
	if (gl_windrect.g_w > maxw)	gl_windrect.g_w = maxw;
	if (gl_windrect.g_h > maxh)	gl_windrect.g_h = maxh;

	if (!st_load_pathnames(fp))				goto out;
	if (!cd_load_preferences(fp))				goto out;

	ret = TRUE;

out :	if (fp) fclose(fp);
	return(ret);
}

/******************************************************************************/
/* End of ST_PREF.C							      */
/******************************************************************************/

