/******************************************************************************/
/* ST_STR.C								      */
/******************************************************************************/

#include "st_def.h"
#include "st_ctype.h"

/******************************************************************************/
/******************************************************************************/

/* -----------------------------------------------------------------------------
 */

unsigned char	*st_memcpy(to, from, n)
register unsigned char	*to;
register unsigned char	*from;
register size_t	n;
{
	if (to != from)
	{
		if (to < from)
		{
			while (n--) { *to++ = *from++; }
		}
		else
		{
			from += (n - 1);
			to += (n - 1);

			while (n--) { *to-- = *from--; }
		}
	}
	return(to);
}

/******************************************************************************/
/******************************************************************************/

/* -----------------------------------------------------------------------------
 */

unsigned char	*st_str_ncpy(to_s, from_s, n)
register unsigned char	*to_s;
register unsigned char	*from_s;
register int	n;
{
	st_memcpy(to_s, from_s, (size_t)n);
	to_s[ n ] = '\0';
	return(to_s);
}

/* -----------------------------------------------------------------------------
 */

unsigned char	*st_str_toupper(s)
register unsigned char 	*s;
{
register int	i;

	for (i = 0 ; s[i] != '\0' ; i ++)
	{
		s[i] = (unsigned char)toupper(s[i]);
	}
	return(s);
}

/* -----------------------------------------------------------------------------
 * Convert a string to lowercase
 */

unsigned char	*st_str_tolower(s)
register unsigned char 	*s;
{
register int	i;

	for (i = 0 ; s[i] != '\0' ; i ++)
	{
		s[i] = (unsigned char)tolower(s[i]);
	}
	return(s);
}

/* -----------------------------------------------------------------------------
 * Removes the leading/trailing blanks from the given string.
 */

unsigned char	*st_str_trim(s)
register unsigned char	*s;
{
register int	i, len;

/* Get rid of leading blanks */

	len = (int)strlen(s);
	i = 0;
	while ((i < len) && (s[i] == ' '))
	{
		i ++;
	}
	if (i)
	{
		len -= i;
		if (len)
		{
			st_memcpy(s, s + i, (size_t)len);
		}
	}

/* Get rid of traling blanks */

	i = len - 1;
	while ((i >= 0) && (s[i] == ' '))
	{
		i --;
	}
	s[ ++i ] = '\0';

	return(s);
}

/* -----------------------------------------------------------------------------
 */

unsigned char	*st_str_squeeze(s)
register unsigned char	*s;
{
register int	i = 0;
register int	j = 0;
register unsigned char	ch;
unsigned char	temps[ MAX_STRLEN ];

	strcpy(temps, s);
	while ((ch = temps[i++]) != '\0')
	{
		if (ch != ' ')
		{
			s[j++] = toupper(ch);
		}
	}
	s[j] = '\0';

	return(s);
}

/* -----------------------------------------------------------------------------
 * returns only the file name from the full path name
 */

unsigned char	*st_str_filename(s)
register unsigned char	*s;
{
register unsigned char	*cp;

	if (cp = strrchr(s, '\\'))
	{
		return(cp + 1);
	}
	return(s);
}

/******************************************************************************/
/******************************************************************************/

/* -----------------------------------------------------------------------------
 * Get the default working directory path name
 */

int	st_get_curpath(pathname)
register unsigned char	pathname[];
{
register unsigned char	*cp;
register int	drv;

	cp = pathname;
	*cp++ = (drv = Dgetdrv()) + 'A';
	*cp++ = ':';

	Dgetpath(cp, drv + 1);
	strcat(pathname, "\\");

	return(TRUE);
}

/* -----------------------------------------------------------------------------
 * Set the default working directory path name
 */

int	st_set_curpath(pathname)
register unsigned char	pathname[];
{
register unsigned char	*cp;
register int	drv;

	if (!(cp = strchr(pathname, ':')))
	{
		return(FALSE);
	}

	drv = cp[-1] - 'A';
	if ((drv < 0) && (drv > 15))
	{
		return(FALSE);
	}

	Dsetdrv(drv);
	cp ++;
	if (Dsetpath(cp))
	{
		return(FALSE);
	}

	return(TRUE);
}

/******************************************************************************/
/* End of ST_STR.C							      */
/******************************************************************************/
